aboutsummaryrefslogtreecommitdiff
path: root/arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h
diff options
context:
space:
mode:
authorGeorgios Pinitas <georgios.pinitas@arm.com>2017-10-23 20:29:30 +0100
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:35:24 +0000
commit81a26ad6b626ce2da83659d7c6c17b6104d1f203 (patch)
tree536807115771f1a4b06048892d1d4e17c98779de /arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h
parent511347a7282b948bddfc071e9a8fa08e79da25b4 (diff)
downloadComputeLibrary-81a26ad6b626ce2da83659d7c6c17b6104d1f203.tar.gz
COMPMID-643: Add bias to CLDepthwiseConvolution.
Change-Id: Ibfe7b8c1172d10cbcae7971fe86b82090519d31d Reviewed-on: http://mpd-gerrit.cambridge.arm.com/92798 Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com> Reviewed-by: Jaroslaw Rzepecki <jaroslaw.rzepecki@arm.com> Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Diffstat (limited to 'arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h')
-rw-r--r--arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h b/arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h
index 4e69f551b8..b3d1eaf3af 100644
--- a/arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h
+++ b/arm_compute/core/CL/kernels/CLDepthwiseConvolution3x3Kernel.h
@@ -49,10 +49,12 @@ public:
*
* @param[in] input Source tensor. DataType supported: F32.
* @param[out] output Destination tensor. Data type supported: Same as @p input.
* @param[in] weights Weights tensor. These are 3D tensors with dimensions [3, 3, IFM]. Data type supported: Same as @p input.
* @param[in] conv_info Padding and stride information to use for the convolution.
*/
- void configure(const ICLTensor *input, ICLTensor *output, const ICLTensor *weights, const PadStrideInfo &conv_info);
+ void configure(const ICLTensor *input, ICLTensor *output, const ICLTensor *weights, const ICLTensor *biases, const PadStrideInfo &conv_info);
// Inherited methods overridden:
void run(const Window &window, cl::CommandQueue &queue) override;
@@ -63,6 +65,7 @@ private:
const ICLTensor *_input;
ICLTensor *_output;
const ICLTensor *_weights;
+ const ICLTensor *_biases;
unsigned int _conv_stride_x;
unsigned int _conv_stride_y;
unsigned int _conv_pad_x;
@@ -49,10 +49,12 @@ public:
* @param[in] input Source tensor. DataType supported: F32.
* @param[out] output Destination tensor. Data type supported: Same as @p input.
- * @param[in] weights Weights tensor. These are 3D tensors with dimensions [3, 3, IFM]. Data type supported: Same as @p input.
+ * @param[in] weights Weights tensor. A 3D tensor with dimensions [3, 3, IFM]. Data type supported: Same as @p input.
+ * @param[in] biases (Optional) Biases tensor. A 1D tensor with dimensions [IFM]. Must be nullptr if not needed.
+ * Data type supported: Same as @p input.
* @param[in] conv_info Padding and stride information to use for the convolution.
*/